@@ -311,6 +311,7 @@ class AssocParserConfig():
         attribute_values = ["{att}={val}".format(att=att, val=dict([(k, v) for k, v in value.items()][:8]) if isinstance(value, dict) else value) for att, value in vars(self).items()]
         return "AssocParserConfig({})".format(",".join(attribute_values))
 
+
 class Report(object):
     """
     A report object that is generated as a result of a parse
@@ -345,7 +346,6 @@ class Report(object):
     RULE_PASS = "Passes GO Rule"
     INVALID_REFERENCES = "Only one reference per ID space allowed"
 
-
     def __init__(self, group="unknown", dataset="unknown", config=None):
         self.messages = []
         self.n_lines = 0
@@ -588,7 +588,6 @@ class AssocParser(object):
                     else:
                         print(line)
 
-
     def skim(self, file):
         """
         Lightweight parse of a file into tuples.
@@ -671,6 +670,34 @@ class AssocParser(object):
                 self.report.error(line.line, Report.INVALID_TAXON, taxon, taxon=taxon)
                 return False
 
+    def _unroll_withfrom_and_replair_obsoletes(self, line: SplitLine, gaf_or_gpad: str, subclassof=None):
+        regrouped_fixed_elements = ''
+        if gaf_or_gpad == 'gaf':
+            withfrom = line.values[7]
+        else:
+            withfrom = line.values[6]
+        for element_set in filter(None, withfrom.split("|")):
+            grouped_fixed_elements = ''
+            for element_individual in filter(None, element_set.split(",")):  # parse the | and ,
+                if element_individual.startswith("GO:"):
+                    fixed_element_individual = self._validate_ontology_class_id(str(element_individual), line)
+                    if fixed_element_individual is None:
+                        return None
+                else:
+                    fixed_element_individual = element_individual
+                if grouped_fixed_elements == '':
+                    grouped_fixed_elements = fixed_element_individual
+                else:
+                    grouped_fixed_elements = grouped_fixed_elements + ',' + fixed_element_individual
+            if regrouped_fixed_elements == '':
+                regrouped_fixed_elements = grouped_fixed_elements
+            else:
+                regrouped_fixed_elements = regrouped_fixed_elements + "|" + grouped_fixed_elements
+        if regrouped_fixed_elements:
+            return association.ConjunctiveSet.str_to_conjunctions(regrouped_fixed_elements)
+        else:
+            return []
+
     # check the term id is in the ontology, and is not obsolete
     def _validate_ontology_class_id(self, id, line: SplitLine, subclassof=None):
         ont = self.config.ontology
@@ -693,7 +720,7 @@ class AssocParser(object):
                         taxon=line.taxon, rule=20)
                     id = rb[0]
                 else:
-                    self.report.warning(line.line, Report.OBSOLETE_CLASS_NO_REPLACEMENT, id, msg="Violates GORULE:0000020",
+                    self.report.error(line.line, Report.OBSOLETE_CLASS_NO_REPLACEMENT, id, msg="Violates GORULE:0000020",
                         taxon=line.taxon, rule=20)
                     id = None
             else:
@@ -761,7 +788,6 @@ class AssocParser(object):
                 valids.append(i)
             else:
                 return None
-
         return sorted(valids)
 
     def validate_curie_ids(self, ids: List[association.Curie], line: SplitLine) -> Optional[List[association.Curie]]:
