@@ -260,7 +260,10 @@ class GafParser(assocparser.AssocParser):
             validated = self.validate_curie_ids(wf.elements, split_line)
             if validated is None:
                 return assocparser.ParseResult(line, [], True)
-
+        with_support_from = self._unroll_withfrom_and_replair_obsoletes(split_line, 'gaf')
+        if with_support_from is None:
+            return assocparser.ParseResult(line, [], True)
+        assoc.evidence.with_support_from = with_support_from
         # validation
         self._validate_symbol(assoc.subject.label, split_line)
 
@@ -333,6 +336,7 @@ class GafParser(assocparser.AssocParser):
 ecomap = EcoMap()
 ecomap.mappings()
 
+
 def to_association(gaf_line: List[str], report=None, group="unknown", dataset="unknown", qualifier_parser=assocparser.Qualifier2_1(), bio_entities=None) -> assocparser.ParseResult:
     report = Report(group=group, dataset=dataset) if report is None else report
     bio_entities = collections.BioEntities(dict()) if bio_entities is None else bio_entities
@@ -391,11 +395,6 @@ def to_association(gaf_line: List[str], report=None, group="unknown", dataset="u
     if gpi_entity is not None and subject != gpi_entity:
         subject = gpi_entity
 
-    aspect = gaf_line[8]
-    negated, relation_label, qualifiers = assocparser._parse_qualifier(gaf_line[3], aspect)
-    # Note: Relation label is grabbed from qualifiers, if any exist in _parse_qualifier
-    qualifiers = [association.Curie.from_str(curie_util.contract_uri(relations.lookup_label(q), strict=False)[0]) for q in qualifiers]
-
     # column 4 is qualifiers -> index 3
     # For allowed, see http://geneontology.org/docs/go-annotations/#annotation-qualifiers
     # We use the below validate to check validaty if qualifiers, not as much to *parse* them into the GoAssociation object.
@@ -406,6 +405,11 @@ def to_association(gaf_line: List[str], report=None, group="unknown", dataset="u
         report.error(source_line, Report.INVALID_QUALIFIER, parsed_qualifiers.original, parsed_qualifiers.message, taxon=gaf_line[TAXON_INDEX], rule=1)
         return assocparser.ParseResult(source_line, [], True, report=report)
 
+    aspect = gaf_line[8]
+    negated, relation_label, qualifiers = assocparser._parse_qualifier(gaf_line[3], aspect)
+    # Note: Relation label is grabbed from qualifiers, if any exist in _parse_qualifier
+    qualifiers = [association.Curie.from_str(curie_util.contract_uri(relations.lookup_label(q), strict=False)[0]) for q in qualifiers]
+
     object = association.Term(association.Curie.from_str(gaf_line[4]), taxon)
     if isinstance(object, association.Error):
         report.error(source_line, Report.INVALID_SYMBOL, gaf_line[4], "Problem parsing GO Term", taxon=gaf_line[TAXON_INDEX], rule=1)
