@@ -140,7 +140,7 @@ class GpadParser(assocparser.AssocParser):
                         logger.info("Detected GPAD version {}, so defaulting to 1.2".format(version))
                         self.version = self.default_version
 
-            return assocparser.ParseResult(line, [{ "header": True, "line": line.strip() }], False)
+            return assocparser.ParseResult(line, [{"header": True, "line": line.strip()}], False)
 
         # At this point, we should have gone through all the header, and a version number should be established
         if self.version is None:
@@ -157,6 +157,9 @@ class GpadParser(assocparser.AssocParser):
 
         split_line = assocparser.SplitLine(line=line, values=vals, taxon="")
 
+        # repair any GO terms in the with/from field that may be obsolete
+        assoc.evidence.with_support_from = self._unroll_withfrom_and_replair_obsoletes(split_line, 'gpad')
+
         valid_goid = self._validate_ontology_class_id(str(assoc.object.id), split_line)
         if valid_goid is None:
             return assocparser.ParseResult(line, [], True)
@@ -164,6 +167,10 @@ class GpadParser(assocparser.AssocParser):
 
         go_rule_results = qc.test_go_rules(assoc, self.config)
         for rule, result in go_rule_results.all_results.items():
+            if isinstance(rule, qc.GoRule28):
+                # ignore result of GORULE:0000028 since aspect check will always fail for GPAD and get repaired
+                continue
+
             if result.result_type == qc.ResultType.WARNING:
                 self.report.warning(line, assocparser.Report.VIOLATES_GO_RULE, "",
                                     msg="{id}: {message}".format(id=rule.id, message=result.message), rule=int(rule.id.split(":")[1]))
@@ -294,7 +301,7 @@ def from_1_2(gpad_line: List[str], report=None, group="unknown", dataset="unknow
             report.error(source_line, Report.INVALID_SYMBOL, gpad_line[4], "Problem parsing references", taxon=str(taxon), rule=1)
             return assocparser.ParseResult(source_line, [], True, report=report)
 
-    withfroms = association.ConjunctiveSet.str_to_conjunctions(gpad_line[6])  # Returns a list of ConjuctiveSets or Error
+    withfroms = association.ConjunctiveSet.str_to_conjunctions(gpad_line[6])
     if isinstance(withfroms, association.Error):
         report.error(source_line, Report.INVALID_SYMBOL, gpad_line[6], "Problem parsing With/From column", taxon=str(taxon), rule=1)
         return assocparser.ParseResult(source_line, [], True, report=report)
