@@ -67,7 +67,9 @@ __relation_label_lookup = bidict({
     "acts upstream of positive effect": "http://purl.obolibrary.org/obo/RO_0004034",
     "located in": "http://purl.obolibrary.org/obo/RO_0001025",
     "is active in": "http://purl.obolibrary.org/obo/RO_0002432",
-    "exists during": "http://purl.obolibrary.org/obo/RO_0002491",
+    "exists during": "http://purl.obolibrary.org/obo/GOREL_0000032",
+    "existence overlaps": "http://purl.obolibrary.org/obo/RO_0002490",
+    "existence starts and ends during": "http://purl.obolibrary.org/obo/RO_0002491",
     "coincident with": "http://purl.obolibrary.org/obo/RO_0002008",
     "has regulation target": "http://purl.obolibrary.org/obo/GOREL_0000015",
     "not happens during": "http://purl.obolibrary.org/obo/GOREL_0000025",
@@ -113,7 +115,10 @@ __relation_label_lookup = bidict({
     "ends with": "http://purl.obolibrary.org/obo/RO_0002230",
     "involved in regulation of": "http://purl.obolibrary.org/obo/RO_0002428",
     "involved in positive regulation of": "http://purl.obolibrary.org/obo/RO_0002429",
-    "involved in negative regulation of": "http://purl.obolibrary.org/obo/RO_0002430"
+    "involved in negative regulation of": "http://purl.obolibrary.org/obo/RO_0002430",
+    "exports": "http://purl.obolibrary.org/obo/RO_0002345",
+    "has primary input": "http://purl.obolibrary.org/obo/RO_0004009",
+    "has primary output": "http://purl.obolibrary.org/obo/RO_0004008",
 })
 
 def lookup_uri(uri, default=None):
